.. include:: references.rst

=============================
Plotting API documentation
=============================

.. automodule:: Ska.engarchive.plot

Classes
-----------
.. autoclass:: Ska.engarchive.plot.MsidPlot
   :show-inheritance:
   :members:
